@@ -792,3 +792,47 @@ typedef HASH mrn_table_def_cache_type;
 #else
 #  define MRN_MI_FLOAT8GET(result, data) mi_float8get((result), (data))
 #endif
+
+#if defined(MRN_MARIADB_P) && (MYSQL_VERSION_ID >= 100400)
+#  define MRN_ITEM_IS_STRING_TYPE(item) \
+  ((item)->is_of_type(Item::CONST_ITEM, STRING_RESULT))
+#  define MRN_ITEM_IS_INT_TYPE(item) \
+  ((item)->is_of_type(Item::CONST_ITEM, INT_RESULT))
+#else
+#  define MRN_ITEM_IS_STRING_TYPE(item) ((item)->type() == Item::STRING_ITEM)
+#  define MRN_ITEM_IS_INT_TYPE(item) ((item)->type() == Item::INT_ITEM)
+#endif
+
+#if defined(MRN_MARIADB_P) && (MYSQL_VERSION_ID >= 100400)
+#  define MRN_ITEM_GET_TIME(item, time, thd)                    \
+  ((item)->get_date((thd), (time), Time::Options((thd))))
+#  define MRN_ITEM_GET_DATE_FUZZY(item, time, thd)                      \
+  ((item)->get_date((thd), (time), Time::Options(TIME_FUZZY_DATES, (thd))))
+#else
+#  define MRN_ITEM_GET_TIME(item, time, thd)    \
+  ((item)->get_time((time)))
+#  define MRN_ITEM_GET_DATE_FUZZY(item, time, thd)      \
+  ((item)->get_date((time), TIME_FUZZY_DATE))
+#endif
+
+#if defined(MRN_MARIADB_P) && (MYSQL_VERSION_ID >= 100400)
+#  define MRN_FIELD_GET_TIME(field, time, thd)  \
+  ((field)->get_date((time), Time::Options((thd))))
+#  define MRN_FIELD_GET_DATE_NO_FUZZY(field, time, thd)  \
+  ((field)->get_date((time), Time::Options(TIME_CONV_NONE, (thd))))
+#else
+#  define MRN_FIELD_GET_TIME(field, time, thd)  \
+  ((field)->get_time((time)))
+#  define MRN_FIELD_GET_DATE_NO_FUZZY(field, time, thd)  \
+  ((field)->get_date((time), 0))
+#endif
+
+#if defined(MRN_MARIADB_P) && (MYSQL_VERSION_ID >= 100400)
+#  define MRN_TABLE_RESET(table) ((table)->reset())
+#  define MRN_TABLE_SHARE_RESET(table_share) ((table_share)->reset())
+#else
+#  define MRN_TABLE_RESET(table) \
+  (memset((table), 0, sizeof(TABLE)))
+#  define MRN_TABLE_SHARE_RESET(table_share) \
+  (memset((table_share), 0, sizeof(TABLE_SHARE)))
+#endif
